@@ -21,9 +21,7 @@
 
 #include "dbusmixerwrapper.h"
 
-#include <QStringList>
 
-#include "core/ControlManager.h"
 #include "core/mixdevice.h"
 #include "core/volume.h"
 #include "kmix_debug.h"
@@ -84,7 +82,7 @@ QString DBusMixerWrapper::driverName()
 QStringList DBusMixerWrapper::controls()
 {
 	QStringList result;
-	for (const shared_ptr<MixDevice> md : qAsConst(m_mixer->getMixSet()))
+    for (const shared_ptr<MixDevice> &md : std::as_const(m_mixer->getMixSet()))
 	{
 		result.append( md->dbusPath() );
 	}
